summaryrefslogtreecommitdiffstats
path: root/korundum
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 21:58:19 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 21:58:19 -0600
commit26abe38d0748c549f2458da57507614fad599d83 (patch)
tree02bc387417c25ba4cc5744f8addf7e3dacf24292 /korundum
parente1a0e352b6ead69ed6f55476272ace842fbbdf74 (diff)
downloadtdebindings-26abe38d0748c549f2458da57507614fad599d83.tar.gz
tdebindings-26abe38d0748c549f2458da57507614fad599d83.zip
Fix retquire
Diffstat (limited to 'korundum')
-rw-r--r--korundum/ChangeLog4
-rw-r--r--korundum/README6
-rwxr-xr-xkorundum/rubylib/examples/RubberDoc.rb4
-rwxr-xr-xkorundum/rubylib/examples/dcop/dcopcall.rb2
-rwxr-xr-xkorundum/rubylib/examples/dcop/dcoppredicate.rb2
-rwxr-xr-xkorundum/rubylib/examples/dcop/dcopsend.rb2
-rwxr-xr-xkorundum/rubylib/examples/dcop/dcopsignal.rb2
-rwxr-xr-xkorundum/rubylib/examples/dcop/dcopslot.rb2
-rwxr-xr-xkorundum/rubylib/examples/dcop/dcoptest.rb2
-rwxr-xr-xkorundum/rubylib/examples/dcop/petshop.rb2
-rw-r--r--korundum/rubylib/examples/kludgeror.rb2
-rw-r--r--korundum/rubylib/examples/kurldemo.rb2
-rw-r--r--korundum/rubylib/examples/menudemo.rb2
-rw-r--r--korundum/rubylib/examples/mimetype.rb2
-rw-r--r--korundum/rubylib/examples/rbKHTMLPart.rb2
-rw-r--r--korundum/rubylib/examples/systray.rb2
-rw-r--r--korundum/rubylib/examples/uikmdi.rb2
-rw-r--r--korundum/rubylib/examples/uimodules/uidialogs.rb2
-rw-r--r--korundum/rubylib/examples/uimodules/uimenus.rb2
-rw-r--r--korundum/rubylib/examples/uimodules/uimisc.rb2
-rw-r--r--korundum/rubylib/examples/uimodules/uiwidgets.rb2
-rw-r--r--korundum/rubylib/examples/uimodules/uixml.rb2
-rw-r--r--korundum/rubylib/examples/uisampler.rb12
-rwxr-xr-xkorundum/rubylib/examples/xmlgui.rb4
-rw-r--r--korundum/rubylib/examples/xmlmenudemo.rb4
-rw-r--r--korundum/rubylib/korundum/Korundum.cpp8
-rw-r--r--korundum/rubylib/korundum/lib/KDE/Korundum.rb2
-rw-r--r--korundum/rubylib/rbkconfig_compiler/README.dox2
-rw-r--r--korundum/rubylib/rbkconfig_compiler/autoexample.rb8
-rw-r--r--korundum/rubylib/rbkconfig_compiler/example.rb4
-rw-r--r--korundum/rubylib/rbkconfig_compiler/kcfg.xsd6
-rw-r--r--korundum/rubylib/rbkconfig_compiler/rbkconfig_compiler.cpp6
-rw-r--r--korundum/rubylib/rbkconfig_compiler/tests/test1main.rb4
-rw-r--r--korundum/rubylib/rbkconfig_compiler/tests/test2main.rb6
-rw-r--r--korundum/rubylib/rbkconfig_compiler/tests/test3main.rb4
-rw-r--r--korundum/rubylib/rbkconfig_compiler/tests/test4main.rb4
-rw-r--r--korundum/rubylib/rbkconfig_compiler/tests/test5main.rb4
-rw-r--r--korundum/rubylib/templates/annotated/basicapp.rb4
-rw-r--r--korundum/rubylib/templates/annotated/menuapp1.rb2
-rw-r--r--korundum/rubylib/templates/annotated/menuapp2.rb6
-rw-r--r--korundum/rubylib/templates/annotated/menuapp3.rb2
-rw-r--r--korundum/rubylib/templates/annotated/minimal.rb2
-rw-r--r--korundum/rubylib/templates/annotated/systray1.rb2
-rw-r--r--korundum/rubylib/templates/basic/basicapp.rb2
-rw-r--r--korundum/rubylib/templates/basic/menuapp1.rb2
-rw-r--r--korundum/rubylib/templates/basic/menuapp2.rb2
-rw-r--r--korundum/rubylib/templates/basic/menuapp3.rb2
-rw-r--r--korundum/rubylib/templates/basic/minimal.rb2
-rw-r--r--korundum/rubylib/templates/basic/systray1.rb2
-rw-r--r--korundum/rubylib/tutorials/p1/p1.rb2
-rw-r--r--korundum/rubylib/tutorials/p2/p2.rb2
-rw-r--r--korundum/rubylib/tutorials/p3/p3.rb2
-rw-r--r--korundum/rubylib/tutorials/p4/p4.rb2
-rw-r--r--korundum/rubylib/tutorials/p5/p5.rb2
-rw-r--r--korundum/rubylib/tutorials/p6/p6.rb2
-rw-r--r--korundum/rubylib/tutorials/p7/p7.rb2
-rw-r--r--korundum/rubylib/tutorials/p8/p8.rb2
-rw-r--r--korundum/rubylib/tutorials/p9/p9.rb2
58 files changed, 89 insertions, 89 deletions
diff --git a/korundum/ChangeLog b/korundum/ChangeLog
index c3236176..3401d5fb 100644
--- a/korundum/ChangeLog
+++ b/korundum/ChangeLog
@@ -121,7 +121,7 @@
2005-05-29 Richard Dale <Richard_Dale@tipitina.demon.co.uk>
- * At the moment retquire 'Qt' and retquire 'Korundum' statements can't appear
+ * At the moment require 'Qt' and require 'Korundum' statements can't appear
in the same ruby program. Suitable fatal error messages are now displayed
to indicate the cause of the problem. Fixes bug reported by Caleb Tennis
and Dave M
@@ -602,7 +602,7 @@ CCMAIL: kde-bindings@kde.org
* Ruby DCOP support now working - here is some example code:
- retquire 'Korundum'
+ require 'Korundum'
class MyWidget < KDE::PushButton
k_dcop 'TQPoint mySlot(int,TQString)'
diff --git a/korundum/README b/korundum/README
index 9c64ba72..5a1614cf 100644
--- a/korundum/README
+++ b/korundum/README
@@ -2,7 +2,7 @@ Please see tdebindings/qtruby/README
KDE Specific Infomation:
- - Instead of retquire 'Qt', use retquire 'Korundum' for KDE programs.
+ - Instead of require 'Qt', use require 'Korundum' for KDE programs.
- The KDE K* classes such as KApplication are renamed as KDE::Application.
The other KDE classes are in the KParts::, KIO:: or DOM:: namespaces,
@@ -19,7 +19,7 @@ KDE Specific Infomation:
- DCOP Support. Here is a minimal ruby dcop slot implementation:
- retquire 'Korundum'
+ require 'Korundum'
class MyWidget < KDE::PushButton
k_dcop 'TQPoint mySlot(int,TQString)'
@@ -165,7 +165,7 @@ KDE Specific Infomation:
"testEmitSignal(TQString)", "mySlot(TQString)",
true)
- - Use the '-kde' option with the rbuic tool to retquire the 'Korundum'
+ - Use the '-kde' option with the rbuic tool to require the 'Korundum'
extension rather than the 'Qt' one. If the '-x' option is used in
conjunction, it generates a KDE top level. For example:
diff --git a/korundum/rubylib/examples/RubberDoc.rb b/korundum/rubylib/examples/RubberDoc.rb
index 50bdc653..a2c5c13b 100755
--- a/korundum/rubylib/examples/RubberDoc.rb
+++ b/korundum/rubylib/examples/RubberDoc.rb
@@ -1,6 +1,6 @@
#!/usr/bin/env ruby
-retquire 'Korundum'
+require 'Korundum'
about = KDE::AboutData.new("one", "two", "three")
KDE::CmdLineArgs.init(ARGV, about)
@@ -827,7 +827,7 @@ module ProjectManager
end
end
- retquire 'yaml'
+ require 'yaml'
def yamlfname
ENV["HOME"] + "/.rubberdocs/projects.yaml"
diff --git a/korundum/rubylib/examples/dcop/dcopcall.rb b/korundum/rubylib/examples/dcop/dcopcall.rb
index 3676525c..cba7ff09 100755
--- a/korundum/rubylib/examples/dcop/dcopcall.rb
+++ b/korundum/rubylib/examples/dcop/dcopcall.rb
@@ -1,6 +1,6 @@
#!/usr/bin/env ruby
-retquire 'Korundum'
+require 'Korundum'
include KDE
class SenderWidget < PushButton
diff --git a/korundum/rubylib/examples/dcop/dcoppredicate.rb b/korundum/rubylib/examples/dcop/dcoppredicate.rb
index 6117643f..82a9c8b4 100755
--- a/korundum/rubylib/examples/dcop/dcoppredicate.rb
+++ b/korundum/rubylib/examples/dcop/dcoppredicate.rb
@@ -1,6 +1,6 @@
#!/usr/bin/env ruby
-retquire 'Korundum'
+require 'Korundum'
include KDE
class SenderWidget < PushButton
diff --git a/korundum/rubylib/examples/dcop/dcopsend.rb b/korundum/rubylib/examples/dcop/dcopsend.rb
index 6511e246..e8a69e00 100755
--- a/korundum/rubylib/examples/dcop/dcopsend.rb
+++ b/korundum/rubylib/examples/dcop/dcopsend.rb
@@ -1,6 +1,6 @@
#!/usr/bin/env ruby
-retquire 'Korundum'
+require 'Korundum'
class SenderWidget < KDE::PushButton
def initialize(parent, name)
diff --git a/korundum/rubylib/examples/dcop/dcopsignal.rb b/korundum/rubylib/examples/dcop/dcopsignal.rb
index f123a62d..4e83d7f4 100755
--- a/korundum/rubylib/examples/dcop/dcopsignal.rb
+++ b/korundum/rubylib/examples/dcop/dcopsignal.rb
@@ -1,6 +1,6 @@
#!/usr/bin/env ruby
-retquire 'Korundum'
+require 'Korundum'
class SenderWidget < KDE::PushButton
k_dcop_signals 'void testEmitSignal(TQString)'
diff --git a/korundum/rubylib/examples/dcop/dcopslot.rb b/korundum/rubylib/examples/dcop/dcopslot.rb
index 99fd6fef..b84eec66 100755
--- a/korundum/rubylib/examples/dcop/dcopslot.rb
+++ b/korundum/rubylib/examples/dcop/dcopslot.rb
@@ -1,6 +1,6 @@
#!/usr/bin/env ruby
-retquire 'Korundum'
+require 'Korundum'
# This is an example of a KDE class that has 'k_dcop' slots declarations, but
# isn't a subclass of DCOPObject. The following four methods are added to your
diff --git a/korundum/rubylib/examples/dcop/dcoptest.rb b/korundum/rubylib/examples/dcop/dcoptest.rb
index c0654fd8..79eb89a4 100755
--- a/korundum/rubylib/examples/dcop/dcoptest.rb
+++ b/korundum/rubylib/examples/dcop/dcoptest.rb
@@ -33,7 +33,7 @@ copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
module DCOPTest
diff --git a/korundum/rubylib/examples/dcop/petshop.rb b/korundum/rubylib/examples/dcop/petshop.rb
index 5847c1f7..bf32bddf 100755
--- a/korundum/rubylib/examples/dcop/petshop.rb
+++ b/korundum/rubylib/examples/dcop/petshop.rb
@@ -5,7 +5,7 @@
# derived from server.py example in tdebindings written by Torben Weis
# and Julian Rockey
-retquire 'Korundum'
+require 'Korundum'
# An object with DCOP slots needn't be a subclass of DCOPObject, but
# this DeadParrotObject is one
diff --git a/korundum/rubylib/examples/kludgeror.rb b/korundum/rubylib/examples/kludgeror.rb
index ca805306..35a42d7e 100644
--- a/korundum/rubylib/examples/kludgeror.rb
+++ b/korundum/rubylib/examples/kludgeror.rb
@@ -4,7 +4,7 @@
# -- gg.
# AK - ported to ruby
-retquire 'Korundum'
+require 'Korundum'
opt = [ [ "+[url]", "An URL to open at startup.", "" ],
[ "z", "A dummy binary option.", "" ],
diff --git a/korundum/rubylib/examples/kurldemo.rb b/korundum/rubylib/examples/kurldemo.rb
index b3d13407..1cd41879 100644
--- a/korundum/rubylib/examples/kurldemo.rb
+++ b/korundum/rubylib/examples/kurldemo.rb
@@ -31,7 +31,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
def initialize(*args)
diff --git a/korundum/rubylib/examples/menudemo.rb b/korundum/rubylib/examples/menudemo.rb
index a6ecada5..44e5b7f0 100644
--- a/korundum/rubylib/examples/menudemo.rb
+++ b/korundum/rubylib/examples/menudemo.rb
@@ -38,7 +38,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
include KDE
class MainWin < MainWindow
diff --git a/korundum/rubylib/examples/mimetype.rb b/korundum/rubylib/examples/mimetype.rb
index 492bd886..170bf461 100644
--- a/korundum/rubylib/examples/mimetype.rb
+++ b/korundum/rubylib/examples/mimetype.rb
@@ -41,7 +41,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
include KDE
class MainWin < MainWindow
diff --git a/korundum/rubylib/examples/rbKHTMLPart.rb b/korundum/rubylib/examples/rbKHTMLPart.rb
index 8fff04c5..8d28e303 100644
--- a/korundum/rubylib/examples/rbKHTMLPart.rb
+++ b/korundum/rubylib/examples/rbKHTMLPart.rb
@@ -42,7 +42,7 @@ lifted from the KDE classref.
=end
-retquire 'Korundum'
+require 'Korundum'
# Note that we use KParts.MainWindow, not KMainWindow as the superclass
# (KParts.MainWindow subclasses KMainWindow). Also, be sure the 'apply'
diff --git a/korundum/rubylib/examples/systray.rb b/korundum/rubylib/examples/systray.rb
index 04d1aa08..b09f0408 100644
--- a/korundum/rubylib/examples/systray.rb
+++ b/korundum/rubylib/examples/systray.rb
@@ -31,7 +31,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
def initialize(*args)
diff --git a/korundum/rubylib/examples/uikmdi.rb b/korundum/rubylib/examples/uikmdi.rb
index 0846388c..e73422eb 100644
--- a/korundum/rubylib/examples/uikmdi.rb
+++ b/korundum/rubylib/examples/uikmdi.rb
@@ -32,7 +32,7 @@ All is not rosy, however:
=end
-retquire 'Korundum'
+require 'Korundum'
include KDE
class KmdiExample < KDE::MdiMainFrm
diff --git a/korundum/rubylib/examples/uimodules/uidialogs.rb b/korundum/rubylib/examples/uimodules/uidialogs.rb
index 72f1ca80..d07177be 100644
--- a/korundum/rubylib/examples/uimodules/uidialogs.rb
+++ b/korundum/rubylib/examples/uimodules/uidialogs.rb
@@ -2,7 +2,7 @@
This is a ruby version of Jim Bublitz's pytde program, translated by Richard Dale
=end
-retquire 'Korundum'
+require 'Korundum'
module UIDialogs
diff --git a/korundum/rubylib/examples/uimodules/uimenus.rb b/korundum/rubylib/examples/uimodules/uimenus.rb
index b213d7e8..dd98f227 100644
--- a/korundum/rubylib/examples/uimodules/uimenus.rb
+++ b/korundum/rubylib/examples/uimodules/uimenus.rb
@@ -2,7 +2,7 @@
This is a ruby version of Jim Bublitz's pytde program, translated by Richard Dale
=end
-retquire 'Korundum'
+require 'Korundum'
module UIMenus
diff --git a/korundum/rubylib/examples/uimodules/uimisc.rb b/korundum/rubylib/examples/uimodules/uimisc.rb
index dad78f5d..bbd0604f 100644
--- a/korundum/rubylib/examples/uimodules/uimisc.rb
+++ b/korundum/rubylib/examples/uimodules/uimisc.rb
@@ -2,7 +2,7 @@
This is a ruby version of Jim Bublitz's pytde program, translated by Richard Dale
=end
-retquire 'Korundum'
+require 'Korundum'
module UIMisc
diff --git a/korundum/rubylib/examples/uimodules/uiwidgets.rb b/korundum/rubylib/examples/uimodules/uiwidgets.rb
index cc2d9a98..5517e416 100644
--- a/korundum/rubylib/examples/uimodules/uiwidgets.rb
+++ b/korundum/rubylib/examples/uimodules/uiwidgets.rb
@@ -2,7 +2,7 @@
This is a ruby version of Jim Bublitz's pytde program, translated by Richard Dale
=end
-retquire 'Korundum'
+require 'Korundum'
module UIWidgets
diff --git a/korundum/rubylib/examples/uimodules/uixml.rb b/korundum/rubylib/examples/uimodules/uixml.rb
index 5763faf3..8abd0c9d 100644
--- a/korundum/rubylib/examples/uimodules/uixml.rb
+++ b/korundum/rubylib/examples/uimodules/uixml.rb
@@ -2,7 +2,7 @@
This is a ruby version of Jim Bublitz's pytde program, translated by Richard Dale
=end
-retquire 'Korundum'
+require 'Korundum'
module UIXML
diff --git a/korundum/rubylib/examples/uisampler.rb b/korundum/rubylib/examples/uisampler.rb
index d1b619b9..ea17fbf6 100644
--- a/korundum/rubylib/examples/uisampler.rb
+++ b/korundum/rubylib/examples/uisampler.rb
@@ -2,13 +2,13 @@
This is a ruby version of Jim Bublitz's pytde program, translated by Richard Dale
=end
-retquire 'Korundum'
+require 'Korundum'
-retquire 'uimodules/uiwidgets.rb'
-retquire 'uimodules/uidialogs.rb'
-retquire 'uimodules/uimenus.rb'
-retquire 'uimodules/uimisc.rb'
-retquire 'uimodules/uixml.rb'
+require 'uimodules/uiwidgets.rb'
+require 'uimodules/uidialogs.rb'
+require 'uimodules/uimenus.rb'
+require 'uimodules/uimisc.rb'
+require 'uimodules/uixml.rb'
$listItems = {"Dialogs" =>
{"KDE::AboutDialog" => ["KDE::AboutApplication", "KDE::AboutContainer", "KDE::ImageTrackLabel",
diff --git a/korundum/rubylib/examples/xmlgui.rb b/korundum/rubylib/examples/xmlgui.rb
index 78896d83..47660ba1 100755
--- a/korundum/rubylib/examples/xmlgui.rb
+++ b/korundum/rubylib/examples/xmlgui.rb
@@ -1,7 +1,7 @@
#!/usr/bin/env ruby
-retquire 'Korundum'
-retquire 'tempfile'
+require 'Korundum'
+require 'tempfile'
about = KDE::AboutData.new("one", "two", "three")
#KDE::CmdLineArgs.init(about)
diff --git a/korundum/rubylib/examples/xmlmenudemo.rb b/korundum/rubylib/examples/xmlmenudemo.rb
index fc1e2459..fbdb51fb 100644
--- a/korundum/rubylib/examples/xmlmenudemo.rb
+++ b/korundum/rubylib/examples/xmlmenudemo.rb
@@ -38,7 +38,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
@@ -294,7 +294,7 @@ end
description = "A basic application template"
version = "1.0"
-# The appName(xmlmenudemo - first argument) is retquired
+# The appName(xmlmenudemo - first argument) is required
# if the program is to automatically locate it *ui.rc file
aboutData = KDE::AboutData.new("xmlmenudemo", "xmlmenudemo",
version, description, KDE::AboutData::License_GPL,
diff --git a/korundum/rubylib/korundum/lib/KDE/Korundum.rb b/korundum/rubylib/korundum/lib/KDE/Korundum.rb
index 4b504579..101d3e30 100644
--- a/korundum/rubylib/korundum/lib/KDE/Korundum.rb
+++ b/korundum/rubylib/korundum/lib/KDE/Korundum.rb
@@ -1 +1 @@
-retquire 'korundum'
+require 'korundum'
diff --git a/korundum/rubylib/rbkconfig_compiler/README.dox b/korundum/rubylib/rbkconfig_compiler/README.dox
index 75f6d826..e345c46a 100644
--- a/korundum/rubylib/rbkconfig_compiler/README.dox
+++ b/korundum/rubylib/rbkconfig_compiler/README.dox
@@ -86,7 +86,7 @@ The following options are read from the kcfgc file:
<td><b>ClassName</b></td>
<td>string</td>
<td>-</td>
- <td>Name of generated class (retquired)</td>
+ <td>Name of generated class (required)</td>
</tr>
<tr>
<td><b>Inherits</b></td>
diff --git a/korundum/rubylib/rbkconfig_compiler/autoexample.rb b/korundum/rubylib/rbkconfig_compiler/autoexample.rb
index c6c942cb..8526c93d 100644
--- a/korundum/rubylib/rbkconfig_compiler/autoexample.rb
+++ b/korundum/rubylib/rbkconfig_compiler/autoexample.rb
@@ -19,10 +19,10 @@
Boston, MA 02110-1301, USA.
=end
-retquire 'Korundum'
-retquire 'exampleprefs_base.rb'
-retquire 'general_base.rb'
-retquire 'myoptions_base.rb'
+require 'Korundum'
+require 'exampleprefs_base.rb'
+require 'general_base.rb'
+require 'myoptions_base.rb'
aboutData = KDE::AboutData.new( "example", I18N_NOOP("autoconfig example"), "0.1" )
aboutData.addAuthor( "Cornelius Schumacher", nil, "schumacher@kde.org" )
diff --git a/korundum/rubylib/rbkconfig_compiler/example.rb b/korundum/rubylib/rbkconfig_compiler/example.rb
index 61e3eb41..d7ef38b1 100644
--- a/korundum/rubylib/rbkconfig_compiler/example.rb
+++ b/korundum/rubylib/rbkconfig_compiler/example.rb
@@ -19,8 +19,8 @@
Boston, MA 02110-1301, USA.
=end
-retquire 'Korundum'
-retquire 'exampleprefs_base.rb'
+require 'Korundum'
+require 'exampleprefs_base.rb'
aboutData = KDE::AboutData.new( "example", I18N_NOOP("cfgc example"), "0.1" )
aboutData.addAuthor( "Cornelius Schumacher", nil, "schumacher@kde.org" )
diff --git a/korundum/rubylib/rbkconfig_compiler/kcfg.xsd b/korundum/rubylib/rbkconfig_compiler/kcfg.xsd
index 943282b9..61450d25 100644
--- a/korundum/rubylib/rbkconfig_compiler/kcfg.xsd
+++ b/korundum/rubylib/rbkconfig_compiler/kcfg.xsd
@@ -88,7 +88,7 @@
<xsd:element minOccurs="0" name="label" type="xsd:string"/>
<xsd:element minOccurs="0" name="whatsthis" type="xsd:string"/>
</xsd:all>
- <xsd:attribute name="name" use="retquired" type="xsd:string"/>
+ <xsd:attribute name="name" use="required" type="xsd:string"/>
</xsd:complexType>
</xsd:element>
</xsd:sequence>
@@ -136,7 +136,7 @@
</xsd:complexType>
</xsd:element>
</xsd:sequence>
- <xsd:attribute name="name" use="retquired" type="xsd:string"/>
+ <xsd:attribute name="name" use="required" type="xsd:string"/>
</xsd:complexType>
</xsd:element>
</xsd:sequence>
@@ -176,7 +176,7 @@
</xsd:complexType>
</xsd:element>
</xsd:sequence>
- <xsd:attribute name="name" use="retquired" type="xsd:string"/>
+ <xsd:attribute name="name" use="required" type="xsd:string"/>
<xsd:attribute name="type" use="optional" type="kcfg:datatype" />
<xsd:attribute name="max" use="optional" type="xsd:positiveInteger"/>
</xsd:complexType>
diff --git a/korundum/rubylib/rbkconfig_compiler/rbkconfig_compiler.cpp b/korundum/rubylib/rbkconfig_compiler/rbkconfig_compiler.cpp
index 2f81e356..bc1114bb 100644
--- a/korundum/rubylib/rbkconfig_compiler/rbkconfig_compiler.cpp
+++ b/korundum/rubylib/rbkconfig_compiler/rbkconfig_compiler.cpp
@@ -429,7 +429,7 @@ CfgEntry *parseEntry( const TQString &group, const TQDomElement &element )
CfgEntry::Choice choice;
choice.name = e2.attribute( "name" );
if ( choice.name.isEmpty() ) {
- kdError() << "Tag <choice> retquires attribute 'name'." << endl;
+ kdError() << "Tag <choice> requires attribute 'name'." << endl;
}
for( n3 = e2.firstChild(); !n3.isNull(); n3 = n3.nextSibling() ) {
TQDomElement e3 = n3.toElement();
@@ -980,10 +980,10 @@ int main( int argc, char **argv )
rb << "# This file is generated by rbkconfig_compiler from " << args->url(0).fileName() << "." << endl;
rb << "# All changes you do to this file will be lost." << endl;
- rb << endl << "retquire 'Korundum'" << endl;
+ rb << endl << "require 'Korundum'" << endl;
if (singleton) {
- rb << "retquire 'singleton'" << endl;
+ rb << "require 'singleton'" << endl;
}
rb << endl;
diff --git a/korundum/rubylib/rbkconfig_compiler/tests/test1main.rb b/korundum/rubylib/rbkconfig_compiler/tests/test1main.rb
index 131287bd..88a151a6 100644
--- a/korundum/rubylib/rbkconfig_compiler/tests/test1main.rb
+++ b/korundum/rubylib/rbkconfig_compiler/tests/test1main.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
-retquire 'test1.rb'
+require 'Korundum'
+require 'test1.rb'
t = Test1.new(nil, nil)
diff --git a/korundum/rubylib/rbkconfig_compiler/tests/test2main.rb b/korundum/rubylib/rbkconfig_compiler/tests/test2main.rb
index bf56014f..85d18f07 100644
--- a/korundum/rubylib/rbkconfig_compiler/tests/test2main.rb
+++ b/korundum/rubylib/rbkconfig_compiler/tests/test2main.rb
@@ -1,5 +1,5 @@
-retquire 'Korundum'
-retquire 'myprefs.rb'
-retquire 'test2.rb'
+require 'Korundum'
+require 'myprefs.rb'
+require 'test2.rb'
t = Test2.new()
diff --git a/korundum/rubylib/rbkconfig_compiler/tests/test3main.rb b/korundum/rubylib/rbkconfig_compiler/tests/test3main.rb
index f6ab27fc..8c19b442 100644
--- a/korundum/rubylib/rbkconfig_compiler/tests/test3main.rb
+++ b/korundum/rubylib/rbkconfig_compiler/tests/test3main.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
-retquire 'test3.rb'
+require 'Korundum'
+require 'test3.rb'
t = TestNameSpace::Test3.new()
diff --git a/korundum/rubylib/rbkconfig_compiler/tests/test4main.rb b/korundum/rubylib/rbkconfig_compiler/tests/test4main.rb
index 87bd2657..c75f0995 100644
--- a/korundum/rubylib/rbkconfig_compiler/tests/test4main.rb
+++ b/korundum/rubylib/rbkconfig_compiler/tests/test4main.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
-retquire 'test4.rb'
+require 'Korundum'
+require 'test4.rb'
t = Test4.instance()
diff --git a/korundum/rubylib/rbkconfig_compiler/tests/test5main.rb b/korundum/rubylib/rbkconfig_compiler/tests/test5main.rb
index 94966a1a..cd0fbeb7 100644
--- a/korundum/rubylib/rbkconfig_compiler/tests/test5main.rb
+++ b/korundum/rubylib/rbkconfig_compiler/tests/test5main.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
-retquire 'test5.rb'
+require 'Korundum'
+require 'test5.rb'
t = Test5.instance()
diff --git a/korundum/rubylib/templates/annotated/basicapp.rb b/korundum/rubylib/templates/annotated/basicapp.rb
index fc5cd2c4..3602a1c6 100644
--- a/korundum/rubylib/templates/annotated/basicapp.rb
+++ b/korundum/rubylib/templates/annotated/basicapp.rb
@@ -31,7 +31,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
=begin
Most Korundum applications will need a main window - the is the top
@@ -70,7 +70,7 @@ aboutData.addAuthor("author2", "they did something else", "another@email.address
# Pass the command line arguments and aboutData to
# KDE::CmdLineArgs - this is where KDE will look for
# this information. The KDE::Application constructor
-# used below *retquires* the args are processed
+# used below *requires* the args are processed
# *before* KDE::Application is instantiated. There
# is an alternate constructor that takes ARGV
# as an argument (see minimal.rb)
diff --git a/korundum/rubylib/templates/annotated/menuapp1.rb b/korundum/rubylib/templates/annotated/menuapp1.rb
index 5a6cb0ac..d65d3272 100644
--- a/korundum/rubylib/templates/annotated/menuapp1.rb
+++ b/korundum/rubylib/templates/annotated/menuapp1.rb
@@ -41,7 +41,7 @@ copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
TOOLBAR_NEW = 1
diff --git a/korundum/rubylib/templates/annotated/menuapp2.rb b/korundum/rubylib/templates/annotated/menuapp2.rb
index 2d4df454..2deca4a5 100644
--- a/korundum/rubylib/templates/annotated/menuapp2.rb
+++ b/korundum/rubylib/templates/annotated/menuapp2.rb
@@ -36,7 +36,7 @@ copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
@@ -65,7 +65,7 @@ class MainWin < KDE::MainWindow
# Create the status bar
initStatusBar()
- # Usings actions, only a single line is retquired
+ # Usings actions, only a single line is required
# to enable/disable both the menu item and corresponding
# toolbar button from anywhere in the program
@saveAction.setEnabled(false)
@@ -111,7 +111,7 @@ class MainWin < KDE::MainWindow
# or you can use KDE::Action.setIcon to set/change the icon. You
# can also add a tooltip with KDE::Action.setToolTip
- # This KAction constructor retquires a string, an accelerator (0
+ # This KAction constructor requires a string, an accelerator (0
# in this case), a slot, and a TQObject (None in this case)
@specialAction = KDE::Action.new(i18n("Special"), KDE::Shortcut.new(0), self, SLOT('slotSpecial()'), actionCollection(), "specialActionName")
diff --git a/korundum/rubylib/templates/annotated/menuapp3.rb b/korundum/rubylib/templates/annotated/menuapp3.rb
index e44cc337..bd701d43 100644
--- a/korundum/rubylib/templates/annotated/menuapp3.rb
+++ b/korundum/rubylib/templates/annotated/menuapp3.rb
@@ -35,7 +35,7 @@ copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
STATUSBAR_LEFT = 1
diff --git a/korundum/rubylib/templates/annotated/minimal.rb b/korundum/rubylib/templates/annotated/minimal.rb
index 45f640dc..e700adc1 100644
--- a/korundum/rubylib/templates/annotated/minimal.rb
+++ b/korundum/rubylib/templates/annotated/minimal.rb
@@ -36,7 +36,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
=begin
diff --git a/korundum/rubylib/templates/annotated/systray1.rb b/korundum/rubylib/templates/annotated/systray1.rb
index 0851c806..cf90ef45 100644
--- a/korundum/rubylib/templates/annotated/systray1.rb
+++ b/korundum/rubylib/templates/annotated/systray1.rb
@@ -37,7 +37,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
# This template uses KDE::MainWindow as the main window widget
# It solves the problem described in systray.rb by using
diff --git a/korundum/rubylib/templates/basic/basicapp.rb b/korundum/rubylib/templates/basic/basicapp.rb
index e3d100b4..3ef34150 100644
--- a/korundum/rubylib/templates/basic/basicapp.rb
+++ b/korundum/rubylib/templates/basic/basicapp.rb
@@ -31,7 +31,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
def initialize(*args)
diff --git a/korundum/rubylib/templates/basic/menuapp1.rb b/korundum/rubylib/templates/basic/menuapp1.rb
index 1b51fc30..69902534 100644
--- a/korundum/rubylib/templates/basic/menuapp1.rb
+++ b/korundum/rubylib/templates/basic/menuapp1.rb
@@ -41,7 +41,7 @@ copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
TOOLBAR_NEW = 1
diff --git a/korundum/rubylib/templates/basic/menuapp2.rb b/korundum/rubylib/templates/basic/menuapp2.rb
index 50216e50..df1cadb2 100644
--- a/korundum/rubylib/templates/basic/menuapp2.rb
+++ b/korundum/rubylib/templates/basic/menuapp2.rb
@@ -36,7 +36,7 @@ copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
diff --git a/korundum/rubylib/templates/basic/menuapp3.rb b/korundum/rubylib/templates/basic/menuapp3.rb
index 5f47a177..7751e847 100644
--- a/korundum/rubylib/templates/basic/menuapp3.rb
+++ b/korundum/rubylib/templates/basic/menuapp3.rb
@@ -35,7 +35,7 @@ copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
STATUSBAR_LEFT = 1
diff --git a/korundum/rubylib/templates/basic/minimal.rb b/korundum/rubylib/templates/basic/minimal.rb
index 47fbe505..aca58cc7 100644
--- a/korundum/rubylib/templates/basic/minimal.rb
+++ b/korundum/rubylib/templates/basic/minimal.rb
@@ -31,7 +31,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
diff --git a/korundum/rubylib/templates/basic/systray1.rb b/korundum/rubylib/templates/basic/systray1.rb
index 32aa0078..b1e5e09b 100644
--- a/korundum/rubylib/templates/basic/systray1.rb
+++ b/korundum/rubylib/templates/basic/systray1.rb
@@ -31,7 +31,7 @@ dealings in this Software without prior written authorization from the
copyright holder.
=end
-retquire 'Korundum'
+require 'Korundum'
class MainWin < KDE::MainWindow
slots 'slotQuitSelected()'
diff --git a/korundum/rubylib/tutorials/p1/p1.rb b/korundum/rubylib/tutorials/p1/p1.rb
index 120f4135..f06c6b3e 100644
--- a/korundum/rubylib/tutorials/p1/p1.rb
+++ b/korundum/rubylib/tutorials/p1/p1.rb
@@ -1,4 +1,4 @@
-retquire 'Qt'
+require 'Qt'
a = TQt::Application.new( ARGV )
diff --git a/korundum/rubylib/tutorials/p2/p2.rb b/korundum/rubylib/tutorials/p2/p2.rb
index b54359da..a9647fef 100644
--- a/korundum/rubylib/tutorials/p2/p2.rb
+++ b/korundum/rubylib/tutorials/p2/p2.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
+require 'Korundum'
about = KDE::AboutData.new("p2", "Hello World", "0.1")
KDE::CmdLineArgs.init(ARGV, about)
diff --git a/korundum/rubylib/tutorials/p3/p3.rb b/korundum/rubylib/tutorials/p3/p3.rb
index f58c0336..67360399 100644
--- a/korundum/rubylib/tutorials/p3/p3.rb
+++ b/korundum/rubylib/tutorials/p3/p3.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
+require 'Korundum'
class MainWindow < KDE::MainWindow
slots 'fileOpen()', 'fileSave()'
diff --git a/korundum/rubylib/tutorials/p4/p4.rb b/korundum/rubylib/tutorials/p4/p4.rb
index f1d8be53..93306c86 100644
--- a/korundum/rubylib/tutorials/p4/p4.rb
+++ b/korundum/rubylib/tutorials/p4/p4.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
+require 'Korundum'
class MainWindow < KDE::MainWindow
slots 'changeLocation()',
diff --git a/korundum/rubylib/tutorials/p5/p5.rb b/korundum/rubylib/tutorials/p5/p5.rb
index c5fb132a..25dd9190 100644
--- a/korundum/rubylib/tutorials/p5/p5.rb
+++ b/korundum/rubylib/tutorials/p5/p5.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
+require 'Korundum'
class MainWindow < KDE::MainWindow
slots 'changeLocation()',
diff --git a/korundum/rubylib/tutorials/p6/p6.rb b/korundum/rubylib/tutorials/p6/p6.rb
index 86ea4ede..e9bdc7e5 100644
--- a/korundum/rubylib/tutorials/p6/p6.rb
+++ b/korundum/rubylib/tutorials/p6/p6.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
+require 'Korundum'
class BookMarkList < KDE::ListView
k_dcop 'void add( TQString )'
diff --git a/korundum/rubylib/tutorials/p7/p7.rb b/korundum/rubylib/tutorials/p7/p7.rb
index 8e6eaf6c..1dca0ddd 100644
--- a/korundum/rubylib/tutorials/p7/p7.rb
+++ b/korundum/rubylib/tutorials/p7/p7.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
+require 'Korundum'
class Browser < KDE::MainWindow
k_dcop 'void setURL(TQString)'
diff --git a/korundum/rubylib/tutorials/p8/p8.rb b/korundum/rubylib/tutorials/p8/p8.rb
index 817f72f9..0d0e5342 100644
--- a/korundum/rubylib/tutorials/p8/p8.rb
+++ b/korundum/rubylib/tutorials/p8/p8.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
+require 'Korundum'
class BookMarkList < KDE::ListView
k_dcop 'void add(TQString)'
diff --git a/korundum/rubylib/tutorials/p9/p9.rb b/korundum/rubylib/tutorials/p9/p9.rb
index 48a01fdc..5ddfeae3 100644
--- a/korundum/rubylib/tutorials/p9/p9.rb
+++ b/korundum/rubylib/tutorials/p9/p9.rb
@@ -1,4 +1,4 @@
-retquire 'Korundum'
+require 'Korundum'
class Browser < KDE::MainWindow
k_dcop 'void setURL(TQString)'
diff --git a/korundum/rubylib/korundum/Korundum.cpp b/korundum/rubylib/korundum/Korundum.cpp
index 66731e95..1ebdcc40 100644
--- a/korundum/rubylib/korundum/Korundum.cpp
+++ b/korundum/rubylib/korundum/Korundum.cpp
@@ -1140,7 +1140,7 @@ void
Init_korundum()
{
if (qt_internal_module != Qnil) {
- rb_fatal("retquire 'Korundum' must not follow retquire 'Qt'\n");
+ rb_fatal("require 'Korundum' must not follow require 'Qt'\n");
return;
}
@@ -1151,9 +1151,9 @@ Init_korundum()
set_kde_resolve_classname(kde_resolve_classname);
// The Qt extension is linked against libsmokeqt.so, but Korundum links against
// libsmokekde.so only. Specifying both a 'retquire Qt' and a 'retquire Korundum',
// would give a link error (see the rb_fatal() error above).
// So call the Init_qtruby() initialization function explicitely, not via 'retquire Qt'
// (Qt.o is linked into libqtruby.so, as well as the Qt.so extension).
Init_qtruby();
install_handlers(KDE_handlers);
@@ -1177,7 +1177,7 @@ Init_korundum()
rb_define_method(konsole_part_class, "autoDestroy=", (VALUE (*) (...)) konsole_part_setautodestroy, 1);
#endif
- rb_retquire("KDE/korundum.rb");
+ rb_require("KDE/korundum.rb");
}
};
@@ -1151,9 +1151,9 @@ Init_korundum()
set_kde_resolve_classname(kde_resolve_classname);
// The Qt extension is linked against libsmokeqt.so, but Korundum links against
- // libsmokekde.so only. Specifying both a 'retquire Qt' and a 'retquire Korundum',
+ // libsmokekde.so only. Specifying both a 'require Qt' and a 'require Korundum',
// would give a link error (see the rb_fatal() error above).
@@ -1151,9 +1151,9 @@ Init_korundum()
// would give a link error (see the rb_fatal() error above).
- // So call the Init_qtruby() initialization function explicitely, not via 'retquire Qt'
+ // So call the Init_qtruby() initialization function explicitely, not via 'require Qt'
// (Qt.o is linked into libqtruby.so, as well as the Qt.so extension).
Init_qtruby();